@@ -62,9 +62,10 @@ def get_args():
     if "providers" in cfg:
         # lets check for the API token
         try:
-            api_token = [
-                i["api_token"] for i in cfg["providers"] if i["name"] == provider
-            ][0]
+            for p in cfg["providers"]:
+                if p['name'] == provider:
+                    api_token = p['api_token']
+                    break
         except IndexError:
             console.print("[red bold]API Tokens are required")
             sys.exit(1)
@@ -149,6 +150,7 @@ def main():
     console.print("Configuring SSH Keys...", end="", style="bold italic")
     # Get Hostname and IP Adress
     output = t.output()
+    print(output)
 
     new_hosts = dict()
     # digitalocean
@@ -157,7 +159,7 @@ def main():
             new_hosts[hostname] = ip_address
             install_ssh_keys(provider, hostname, ip_address)
 
-    # linode
+    # linode, aws
     elif "instance_ip_address" in output:
         for hostname, ip_address in output["instance_ip_address"]["value"].items():
             new_hosts[hostname] = ip_address
